"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChildProcessService = void 0;
const child_process_1 = require("child_process");
class ChildProcessService {
    constructor() { }
    static get instance() {
        if (!this.pInstance) {
            this.pInstance = new ChildProcessService();
        }
        return this.pInstance;
    }
    static reset() {
        this.pInstance = null;
    }
    /**
     * Execute command
     * @param {string} executable
     * @param {any[]} args
     * @param {string} wd
     * @param {object} on stdout/stderr handlers
     * @return {Promise<number>}
     */
    exec(executable, args, wd, on) {
        return __awaiter(this, void 0, void 0, function* () {
            let exitCode = -1;
            yield new Promise((resolve, reject) => {
                const process = child_process_1.spawn(executable, args, {
                    cwd: wd,
                    shell: true,
                });
                if (on && on.stdout) {
                    process.stdout.on('data', (data) => {
                        on.stdout(data);
                    });
                }
                if (on && on.stderr) {
                    process.stderr.on('data', (data) => {
                        on.stderr(data);
                    });
                }
                if (on && on.process) {
                    on.process(process);
                }
                let error;
                /* istanbul ignore next */
                process.on('error', (e) => {
                    error = e;
                });
                process.on('close', (code) => {
                    exitCode = code;
                    /* istanbul ignore next */
                    if (error) {
                        exitCode = -1;
                        return reject(error);
                    }
                    resolve();
                });
            });
            return exitCode;
        });
    }
}
exports.ChildProcessService = ChildProcessService;
//# sourceMappingURL=ChildProcessService.js.map