"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TempPathsRegistry = void 0;
const utils_1 = require("../utils");
const tmp = require('tmp-promise');
class TempPathsRegistry {
    constructor() {
        this.tempPaths = [];
    }
    static get instance() {
        if (!this.pInstance) {
            this.pInstance = new TempPathsRegistry();
        }
        return this.pInstance;
    }
    static reset() {
        this.pInstance = null;
    }
    createTempDir(keep = false) {
        return __awaiter(this, void 0, void 0, function* () {
            const dir = yield tmp.dir({
                keep,
            });
            if (!keep) {
                this.tempPaths.push(dir.path);
            }
            return dir.path;
        });
    }
    createTempFile(keep = false, postfix) {
        return __awaiter(this, void 0, void 0, function* () {
            const file = yield tmp.file({
                keep,
                postfix,
            });
            if (!keep) {
                this.tempPaths.push(file.path);
            }
            return file.path;
        });
    }
    cleanup() {
        return __awaiter(this, void 0, void 0, function* () {
            yield Promise.all(this.tempPaths.map((path) => utils_1.FSUtil.remove(path, true)));
        });
    }
}
exports.TempPathsRegistry = TempPathsRegistry;
//# sourceMappingURL=TempPathsRegistry.js.map