"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateUtilitiesRegistry = void 0;
class TemplateUtilitiesRegistry {
    constructor() {
        this.cleanup();
    }
    static get instance() {
        if (!this.pInstance) {
            this.pInstance = new TemplateUtilitiesRegistry();
        }
        return this.pInstance;
    }
    static reset() {
        this.pInstance = null;
    }
    /**
     * Register template utilities
     * @param {ITemplateUtility} templateUtility
     * @return {TemplateUtilitiesRegistry}
     */
    register(...templateUtility) {
        this.registry.push(...templateUtility);
        return this;
    }
    /**
     * Unregister template utilities
     * @param {ITemplateUtility} templateUtility
     * @return {TemplateUtilitiesRegistry}
     */
    unregister(...templateUtility) {
        for (const utility of templateUtility) {
            this.registry.splice(this.registry.indexOf(utility), 1);
        }
        return this;
    }
    /**
     * Generate utilities for tempalte
     * @param {IContext} context action context
     * @param {ActionSnapshot} snapshot action snapshot
     * @param {IDelegatedParameters} parameters action parameters
     * @param {string} wd working directory
     * @return {{[key: string]: any}}
     */
    generateUtilities(context, snapshot, parameters, wd) {
        const result = {};
        for (const utility of this.registry) {
            Object.assign(result, utility.getUtilities(context, snapshot, parameters, wd));
        }
        return result;
    }
    /**
     * Cleanup registry
     * @return {ActionHandlersRegistry}
     */
    cleanup() {
        this.registry = [];
        return this;
    }
}
exports.TemplateUtilitiesRegistry = TemplateUtilitiesRegistry;
//# sourceMappingURL=TemplateUtilitiesRegistry.js.map